Module configs

Module configs 

generates Infos required to compile and then run a program

Modules

gen
util
with_base
with_command_running
with_fs
with_get
with_iters
with_list
with_math
with_multithreading
with_stdio
with_string

Structs

Config
Usage: create an empty Config using Config::new(), use the methods to customize it, then get the Infos using Config::infos() bundle_* for bundles (combines multiple groups or even bundles) with_* for usage-oriented groups add_* to add custom things