generates Infos required to compile and then run a program
Modules
- gen
- util
- with_
base - with_
command_ running - with_fs
- with_
get - with_
iters - with_
list - with_
math - with_
multithreading - with_
stdio - with_
string
Structs
- Config
- Usage: create an empty Config using Config::new(), use the methods to customize it, then get the Infos using Config::infos() bundle_* for bundles (combines multiple groups or even bundles) with_* for usage-oriented groups add_* to add custom things